# Devision Developers Cli Lib

You need Python 3.6+

## Motivation

When you have many projects, you should experience minimal pain in accompanying.

General rules for code design, test runs should not change from project to project, should not cause constant discussion and give the opportunity to fix them directly in one of their projects.

## Install

```shell script
pip install ddc
```
or 
```shell script
pip3 install ddc
```


Check install:
```shell script
ddc version
```

For exit from help press key "q" 